package com.xuqm.server.appmanager.interceptor;

import com.auth0.jwt.exceptions.AlgorithmMismatchException;
import com.auth0.jwt.exceptions.SignatureVerificationException;
import com.auth0.jwt.exceptions.TokenExpiredException;
import com.xuqm.server.appmanager.common.JWTHelper;
import com.xuqm.server.appmanager.common.json.GsonImplHelp;
import com.xuqm.server.appmanager.http.HttpResult;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.web.servlet.HandlerInterceptor;

public class JWTInterceptor implements HandlerInterceptor {

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        String msg = "";
        //获取请求头中令牌
        String token = request.getHeader("token");
        try {
            JWTHelper.verify(token);//验证令牌
            return true;//放行请求
        } catch (SignatureVerificationException e) {
            msg = "无效签名!";
        } catch (TokenExpiredException e) {
            msg = "token过期!";
        } catch (AlgorithmMismatchException e) {
            msg = "token算法不一致!";
        } catch (Exception e) {
            msg = "token无效!!";
        }
        HttpResult<String> result = new HttpResult<>(401, msg, null);
        //将map 专为json  jackson
        response.setContentType("application/json;charset=UTF-8");
        response.getWriter().println(GsonImplHelp.get().toJson(result));
        return false;
    }
}

